# peony

### 一. 概述

peony是专门配合maple来使用的，其具体架构为:

    gateway/ws_gateway -> broker -> peony
          ^                           |
          |                           |
          +-------- forwarder --------+

### 二. 适用场景

* 单人联网的逻辑复杂游戏
* 玩家间的交互非常少

比如修仙模拟器，其计算逻辑非常复杂，计算依赖的数据量也很大，比如进入副本之后的战斗。
如果每次客户端请求都先加载一遍数据，计算完再返回给客户端，对性能的消耗太大了。

如果试用peony的话，就可以让某个玩家固定路由到某台peony.worker上，其数据在第一次请求的时候加载进入worker内存中，之后的请求就不用再加载了。
然后定时将内存的数据写入到磁盘(leveldb)或者其它存储(redis)中。

peony中还自带了定时器功能，所以可以很方便的实现定时处理的事件。如定时获得资源，或者定时写入磁盘等。


